"""Video File Organizer with AI Translation."""

__version__ = "2.0.3"
__author__ = "Rafli"
__email__ = "hidayattul.rafli@gmail.com"
__url__ = "https://github.com/hdytrfli/nichi"
__description__ = "A TUI tool for organizing video files, converting VTT subtitles to SRT format, and translating SRT files using Google Gemini AI."
